********************************************************************************
*Piper-Lewis Vacancies and Performance Project
*June, 2022
*Data: jpart_self_perf_060222.xlsx
********************************************************************************
import excel "C:\Users\lewisde\Dropbox\Vacancies and Performance\jpart_self_perf_060222.xlsx", sheet("Sheet1") firstrow
 
**Create some necessary variables
generate mvac= (1+Total_Vacant_Days)/30
generate dpm = directPAS*mvac
generate emp = employ16/1000

**First, regressions with agency performance.

label variable mvac "Months Vacant (0-42)"
label variable direct "Direct PAS Leader (0,1)"
label variable dpm "Months*Direct PAS"
label variable eop "EOP (0,1)"
label variable offsec "Office of the Secretary (0,1)"
label variable indcom "Independent Commission (0,1)"
label variable emp "Employees (1000s)"
label variable dem "%Democratic Respondents"
label variable appt "%Appointee Respondents"
label variable turnpas "Turnover: #PAS Appointees (0-3)"
label variable skills_mean_2014 "Workforce Skill -- Obama Administration"
label variable depprior "Priority Department (0,1)"
label variable bprior "Priority Bureau (0,1)"
label variable ideo_rating "Agency Ideology (L-C)"
label variable tott "Leadership Transitions (0-4)"
label variable selin_dm_ind "Decision Maker Independence"
label variable selin_pr_ind "Independence from Political Review"
label variable Obama_Vacancy "Number of Vacant Days--Obama"
label variable Bush_Vacancy_Length_Total "Number of Vacant Days--Bush"
label variable Trump_Time_Nomination "Days to First Nomination"

*******************************INFERENCE PART***********************************
**Inference models (Appendix A): These models try to determine whether vacancy lenght is endogenous to performance
**by regressing vacancy lenght on the health of the agency in 2014, using the 2014 workforce skills ratings from
**Richardson et al. 2018.

reg mvac skills_mean_2014 offsec eop indcom depp bprior ideo_rating emp if agency_perf~=.&direct==1, cluster(dept)
outreg using p_l_table1.docx , replace  bdec(3) starlevels(10 5) varlabels title (Figure A1. Models of PAS Position Vacancy Length, 2017-2020)stats(b se p)


**Models only with high skill agencies (Appendix B): The coefficient on workforce skills was not precise but it was
**negative, suggesting perhaps that high skill agencies had fewer vacancies. So, we estimate regressions on different
**skill levels.

summarize skills_mean_2014, detail

reg agency_perf mvac tott eop offsec indcom depp bp if directPAS==1&skills_mean_2014>-.03058, cluster(dept)

outreg, replace bdec(3) starlevels(10 5) varlabels ctitles ("Agency Performance (1-5)" "50th Percentile") stats(b se p)

reg agency_perf mvac tott eop offsec indcom depp bp if directPAS==1&skills_mean_2014>.5050808, cluster(dept)

outreg, replace  bdec(3) starlevels(10 5) varlabels merge ctitles ("" "75th Percentile") stats(b se p)

reg agency_perf mvac tott eop offsec indcom depp bp if directPAS==1&skills_mean_2014>.9451265, cluster(dept)

outreg, replace  bdec(3) starlevels(10 5) varlabels merge ctitles("" "90th Percentile") title (Figure B1. Models of Agency Performance With Only High Skilled Agencies, 2020) stats(b se p)

**Summary statistics for key variables
summarize agency_perf mvac tott skills_mean_2014 offsec eop indcom emp dem appt depp bp if direct==1& agency_perf~=., detail
corr agency_perf mvac
corr agency_perf mvac if direct==1
corr agency_perf skills_mean_2014 if direct==1
corr agency_perf turnpas
corr tott mvac
corr emp agency_perf
corr dem agency_perf
corr appt agency_perf

********************************MAIN ANALYSIS***********************************
**TABLE 1


**Model 1
reg agency_perf mvac if directPAS==1, cluster(dept)
outreg, replace bdec(3) starlevels(10 5) varlabels ctitles ("Agency Performance (1-5)") stats(b se p)
 
**Model 2

reg agency_perf mvac tott eop offsec indcom depp bp if directPAS==1, cluster(dept)
outreg, replace bdec(3) starlevels(10 5) varlabels merge ctitles ("Agency Performance") stats(b se p)

**Model 3

reg agency_perf mvac tott skills_mean_2014 offsec eop indcom emp dem appt if directPAS==1, cluster(dept)
outreg, replace bdec(3) starlevels(10 5) varlabels merge ctitles ("Agency Performance") title (Table 1. OLS Estimates of Models of Self-Reported Agency Performance, 2020) stats(b se p)

**TABLE 1 ROBUSTNESS

**Agency ideology
reg agency_perf mvac tott eop offsec indcom depp bp ideo_rating if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance" "Agency Ideology")

**Log of employment
generate lnemp= ln(.01+emp)
reg agency_perf mvac tott eop offsec indcom depp bp lnemp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Logged Employment")

**Jacknife Errors
reg agency_perf mvac tott eop offsec indcom depp bp if directPAS==1, vce(jack)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Jacknife Errors")

**KRLS
krls agency_perf mvac tott eop offsec indcom depp bp if directPAS==1
*outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "KRLS Estimates")

**Functional Form
generate mvsq=mvac^2
reg agency_perf mvac mvsq tott eop offsec indcom depp bp if directPAS==1, cluster(dept)

test mvac=mvac+mvsq

**Interact with Skills Rating
generate mvsk=mvac*skills_mean_2014
label variable mvsk "Months Vacant*Workforce Skill"

reg agency_perf mvac tott skills_mean_2014 mvsk eop offsec indcom depp bp if directPAS==1, cluster(dept)

test  mvac+skills_mean_2014=mvac+mvsk+skills_mean_2014
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance (1-5)" "")

reg agency_perf mvac tott skills_mean_2014 mvsk offsec eop indcom emp dem appt if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance") title (Table 1. OLS Estimates of Models of Self-Reported Agency Performance, 2020)

**Interact with turnover
generate mvtt=mvac*tott
reg agency_perf mvac tott mvtt eop offsec indcom depp bp if directPAS==1, cluster(dept)


**Table A1 Robustness: R1 Models

**Selin_dm
reg agency_perf mvac tott  depp bp selin_dm_ind selin_pr_ind if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance" "Continuous Measure Insulation")

**Selin interaction # 1
generate mv_sel_dm=mvac*selin_dm_ind

label variable mv_sel_dm "Months Vacant*Decision Maker Ind."
reg agency_perf mvac tott depp bp selin_dm_ind mv_sel_dm  if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Continuous Measure Insulation")

test _cons+selin_dm_ind+ mv_sel_dm =  _cons+selin_dm_ind

**Selin interaction # 2
generate mv_sel_pr=mvac*selin_pr_ind
reg agency_perf mvac tott depp bp selin_pr_ind mv_sel_pr  if directPAS==1, cluster(dept)

test _cons+selin_pr_ind+ mv_sel_pr =  _cons+selin_pr_ind

label variable mv_sel_pr "Months Vacant*Political Rev. Ind."
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Continuous Measure Insulation")

**Table A2 Robustness: Professionalization
generate pctprof=professionals16/employ16
generate mv_pct_prof=mvac*pctprof
label variable pctprof "%Professionals"
label variable mv_pct_prof "Months Vacant*%Professionals"

reg agency_perf mvac tott eop offsec indcom depp bp pctprof  if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance" "Pct Professional")

reg agency_perf mvac tott eop offsec indcom depp bp pctprof mv_pct_prof  if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Pct Professional")

test _cons+pctprof + mv_pct_prof = _cons+pctprof

**Table A3 Robustness: Vacancy Frequency
**Vacancy Frequency--Obama
generate obama_vac_months=Obama_Vacancy/30
generate mv_obama_vac=mvac*obama_vac_months
label variable obama_vac_months "Vacant Months(Obama)"
label variable mv_obama_vac "Months Vacant*Vacant Months(Obama)"

reg agency_perf mvac tott eop offsec indcom depp bp obama_vac_months  if directPAS==1
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance" "Obama Vacancy Frequency")

reg agency_perf mvac tott eop offsec indcom depp bp obama_vac_months mv_obama_vac if directPAS==1
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance" "Obama Vacancy Frequency")

test _cons+obama_vac_months + mv_obama_vac = _cons+obama_vac_months

**Vacancy Frequency--Bush
generate bush_vac_months=Bush_Vacancy/30
generate mv_bush_vac=mvac*bush_vac_months
label variable bush_vac_months "Vacant Months(Bush)"
label variable mv_bush_vac "Months Vacant*Vacant Months(Bush)"

reg agency_perf mvac tott eop offsec indcom depp bp bush_vac_months  if directPAS==1
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Bush Vacancy Frequency")

reg agency_perf mvac tott eop offsec indcom depp bp bush_vac_months mv_bush_vac if directPAS==1
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Bush Vacancy Frequency")

test _cons+bush_vac_months+ mv_bush_vac = _cons+bush_vac_months

**Table A4: Leadership Turnover
**# Leaders--Obama
label variable Obama_Number_PAS "#PAS Leaders(Obama)"
generate mv_obama_pas=mvac*Obama_Number_PAS
label variable mv_obama_pas "Months Vacant*#PAS Leaders(Obama)"

reg agency_perf mvac tott eop offsec indcom depp bp Obama_Number_PAS  if directPAS==1
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance" "Obama # PAS Leaders")

reg agency_perf mvac tott eop offsec indcom depp bp Obama_Number_PAS mv_obama_pas  if directPAS==1
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Obama # PAS Leaders")

test _cons+Obama_Number_PAS+ mv_obama_pas = _cons+Obama_Number_PAS

**# Leaders Frequency--Bush
label variable Bush_Number_PAS "#PAS Leaders(Bush)"
generate mv_bush_pas=mvac*Bush_Number_PAS
label variable mv_bush_pas "Months Vacant*#PAS Leaders(Bush)"
reg agency_perf mvac tott eop offsec indcom depp bp Bush_Number_PAS  if directPAS==1
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Bush # PAS Leaders")

reg agency_perf mvac tott eop offsec indcom depp bp Bush_Number_PAS mv_bush_pas  if directPAS==1
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Bush # PAS Leaders")

test _cons+Bush_Number_PAS + mv_bush_pas = _cons+Bush_Number_PAS

**Table 2

summarize invest_now fevs_agency sense sup_misn_app sup_misn_wh sup_misn_comm if direct==1

reg invest_now mvac tott offsec eop indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("" "Invest Now")

reg fevs_agency mvac tott offsec eop indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Agency Satisfaction")

reg sense mvac tott offsec eop indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Sense of Urgency")

reg sup_misn_app mvac tott offsec eop indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Appointee Supp")

reg sup_misn_wh mvac tott offsec eop indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "WH Support")

reg sup_misn_comm mvac tott offsec eop indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Comm. Support")



**Appendix E

**INVESTMENTS
**Model 1
reg invest_now mvac if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Invest Now (0-4)")
 
**Model 2

reg invest_now mvac tott eop offsec indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Invest Now (0-4)")

**Model 3

reg invest_now mvac tott skills_mean_2014 offsec eop indcom emp dem appt if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Invest Now (0-4)") title (Table 1. OLS Estimates of Models of Investing in Future, 2020)


**MORALE

reg fevs_agency mvac if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Satisfaction-Agency (0-4)")
 
**Model 2

reg fevs_agency mvac tott eop offsec indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Satisfaction-Agency (0-4)")

**Model 3

reg fevs_agency mvac tott skills_mean_2014 offsec eop indcom emp dem appt if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Satisfaction-Agency (0-4)") title (Table 1. OLS Estimates of Morale, 2020)


**MOTIVATION


reg sense mvac if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Sense of Urgency (0-4)")
 
**Model 2

reg sense mvac tott eop offsec indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Sense of Urgency (0-4)")

**Model 3

reg sense mvac tott skills_mean_2014 offsec eop indcom emp dem appt if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Sense of Urgency (0-4)") title (Table 1. OLS Estimates of Sense of Urgency, 2020)


**APPOINTEES

reg sup_misn_app mvac if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Support Mission-Appointees")
 
**Model 2

reg sup_misn_app mvac tott eop offsec indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Support Mission-Appointees")

**Model 3

reg sup_misn_app mvac tott skills_mean_2014 offsec eop indcom emp dem appt if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Support Mission-Appointees") title (Table 1. OLS Estimates of Appointee Investment in Agency Capacity, 2020)


**WHITE HOUSE

reg sup_misn_wh mvac if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Support Mission-WH")
 
**Model 2

reg sup_misn_wh mvac tott eop offsec indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Support Mission-WH")

**Model 3

reg sup_misn_wh mvac tott skills_mean_2014 offsec eop indcom emp dem appt if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Support Mission-WH") title (Table 1. OLS Estimates of White House Investment in Agency Capacity, 2020)

**CONGRESSIONAL COMMITTEES

reg sup_misn_comm mvac if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Support Mission-Committees")
 
**Model 2

reg sup_misn_comm mvac tott eop offsec indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Support Mission-Committees")

**Model 3

reg sup_misn_comm mvac tott skills_mean_2014 offsec eop indcom emp dem appt if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Support Mission-Committees") title (Table 1. OLS Estimates of Committee Investment in Agency Capacity, 2020)


**Appendix F: Effectively Managed and Well Run. These look similar. The small number of cases is a problem. If I we estimate models with skills but not emp, dem, appt, things look the same. **Similarly, if we estimate with emp, dem, appt and not skills, results look the same.

*Model 1
reg eff_mng_org mvac if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance (1-5)")
 
**Model 2

reg eff_mng_org mvac tott eop offsec indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance")

**Model 3

reg eff_mng_org mvac tott skills_mean_2014 offsec eop indcom emp dem appt if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance") title (Table 1. OLS Estimates of Models of Reports of Effectively Managed Organization, 2020)



**Appendix G: Other Mechanisms

summarize deal_poor_perf invexp if direct==1 

reg deal_poor_perf mvac tott offsec eop indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("" "Deal Poor Performers")

reg invexp mvac tott offsec eop indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Invest Expertise")


***************************************************************************************************************************************************************************************************************
**Analyses not in the paper but for the research program moving forward

**TABLE 1 Replicated with the Performance Ratings of Richardson


**Model 1
reg perf_rating_inf mvac if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance (1-5)")
 
**Model 2

reg perf_rating_inf mvac turnpas eop offsec Bureau indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance")

**Model 3

reg perf_rating_inf mvac turnpas skills_mean_2014 offsec Bureau eop indcom if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance") title (Table 1. OLS Estimates of Models of Self-Reported Agency Performance, 2020)


********************************************
**Table 1 Replicated with BPTW


**Model 1
reg beptw mvac if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("COVID Performance (0-100)")
 
**Model 2

reg beptw mvac tott eop offsec indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("COVID Performance (0-100)")

**Model 3

reg beptw mvac tott skills_mean_2014 offsec eop indcom emp dem appt if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("COVID Performance (0-100)") title (Table 1. OLS Estimates of Models of Self-Reported Agency Performance, 2020)

********************************************
**Table 1 Replicated with Days to Confirm
generate mconf=(1+Days_2)/30
label variable mconf "Number of Months Before 1st Nominee Conf."

**Model 1
reg agency_perf mconf if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance (1-5)")
 
**Model 2

reg agency_perf mconf tott eop offsec indcom depp bp if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance")

**Model 3

reg agency_perf mconf tott skills_mean_2014 offsec eop indcom emp dem appt if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance") title (Table 1. OLS Estimates of Models of Self-Reported Agency Performance, 2020)

********************************************
**Table 1 Replicated with Ideology Rating


**Model 1
reg agency_perf mvac ideo_rating if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance (1-5)")
 
**Model 2

reg agency_perf mvac tott eop offsec indcom depp bp ideo_rating if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance")

**Model 3

reg agency_perf mvac tott skills_mean_2014 offsec eop indcom ideo_rating emp dem appt if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance") title (Table 1. OLS Estimates of Models of Self-Reported Agency Performance, 2020)


********************************************
**Table 1 Replicated with Partisan Disagreement
label variable pty_dis_str "Strength of Partisan Disagreement over Agency (1-5)"


**Model 1
reg agency_perf mvac pty_dis_str if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance (1-5)")
 
**Model 2

reg agency_perf mvac tott eop offsec indcom depp bp ideo_rating pty_dis_str if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance")

**Model 3

reg agency_perf mvac tott skills_mean_2014 offsec eop indcom ideo_rating emp dem appt pty_dis_str if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance") title (Table 1. OLS Estimates of Models of Self-Reported Agency Performance, 2020)


********************************************
**Table 1 Replicated with Statutory Discretion
label variable mngt_statutes "Statutory Discretion (1-5)"


**Model 1
reg agency_perf mvac  mngt_statutes if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance (1-5)")
 
**Model 2

reg agency_perf mvac tott eop offsec indcom depp bp ideo_rating mngt_statutes if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance")

**Model 3

reg agency_perf mvac tott skills_mean_2014 offsec eop indcom ideo_rating emp dem appt mngt_statutes if directPAS==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance") title (Table 1. OLS Estimates of Models of Self-Reported Agency Performance, 2020)


********************************************
**Models with liberal and conservative agencies separate. These are models estimated, dividing up the data into agencies above and below the median in ideology.

**Model 1
reg agency_perf mvac if directPAS==1&ideo_rating<-0.007, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance (1-5)""Liberal")
 
**Model 2

reg agency_perf mvac tott eop offsec indcom depp bp if directPAS==1 &ideo_rating<-0.007 , cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance""Liberal")

**Model 3

reg agency_perf mvac tott skills_mean_2014 offsec eop indcom emp dem appt if directPAS==1 &ideo_rating<-0.007, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance""Liberal")

**Model 4
reg agency_perf mvac if directPAS==1&ideo_rating>-0.007, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance (1-5)""Conservative")
 
**Model 5

reg agency_perf mvac tott eop offsec indcom depp bp if directPAS==1&ideo_rating>-0.007, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance""Conservative")

**Model 6

reg agency_perf mvac tott skills_mean_2014 offsec eop indcom emp dem appt if directPAS==1&ideo_rating>-0.007, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance""Conservative") title (Table 1. OLS Estimates of Models of Self-Reported Agency Performance, 2020)

**Models with priority and non-priroity agencies separate. 

**Model 1
reg agency_perf mvac if directPAS==1&depp==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance (1-5)""Pres. Priority")
 
**Model 2

reg agency_perf mvac tott eop offsec indcom if directPAS==1 &depp==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance""Pres. Priority")

**Model 3

reg agency_perf mvac tott skills_mean_2014 offsec eop indcom emp dem appt if directPAS==1 &depp==1, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance""Pres. Priority")

**Model 4
reg agency_perf mvac if directPAS==1&depp==0, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance (1-5)""No Priority")
 
**Model 5

reg agency_perf mvac tott eop offsec indcom if directPAS==1&depp==0, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance""No Priority")

**Model 6

reg agency_perf mvac tott skills_mean_2014 offsec eop indcom emp dem appt if directPAS==1&depp==0, cluster(dept)
outreg, replace se bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("Agency Performance""No Priority") title (Table 1. OLS Estimates of Models of Self-Reported Agency Performance, 2020)


**Models with different ideologies.

reg agency_perf mvac tott eop offsec indcom depp bp if directPAS==1&ideo_rating<0, cluster(dept)

outreg, replace bdec(3) squarebrack starlevels(10 5) varlabels ctitles ("Agency Performance (1-5)" "Liberal Agencies") stats(b se p)

reg agency_perf mvac tott eop offsec indcom depp bp if directPAS==1&ideo_rating>0, cluster(dept)

outreg, replace bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Conservative Agencies") stats(b se p)

reg agency_perf mvac tott eop offsec indcom depp bp if directPAS==1&depp==1, cluster(dept)

outreg, replace bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles ("" "Presidential Priority Agencies") stats(b se p)

reg agency_perf mvac tott eop offsec indcom depp bp if directPAS==1&depp==0, cluster(dept)

outreg, replace bdec(3) squarebrack starlevels(10 5) varlabels merge ctitles("" "No Presidential Priority") title (Figure X. Models of Agency Performance With Agencies Prseidents Target and Do Not Target, 2020) stats(b se p)
